==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/el/lang.php <==
<?php
/**
 * Greek language file
 *
 * Based on DokuWiki Version rc2007-05-24 english language file
 * Original english language file contents included for reference
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Christopher Smith <chris@jalakai.co.uk>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 */
$lang['menu']                  = 'Διαχείριση Επεκτάσεων';
$lang['download']              = 'Κατεβάστε και εγκαταστήστε μια νέα επέκταση (plugin)';
$lang['manage']                = 'Εγκατεστημένες επεκτάσεις';
$lang['btn_info']              = 'πληροφορίες';
$lang['btn_update']            = 'ενημέρωση';
$lang['btn_delete']            = 'διαγραφή';
$lang['btn_settings']          = 'ρυθμίσεις';
$lang['btn_download']          = 'Μεταφόρτωση';
$lang['btn_enable']            = 'Αποθήκευση';
$lang['url']                   = 'URL';
$lang['installed']             = 'Εγκατεστημένη:';
$lang['lastupdate']            = 'Τελευταία ενημέρωση:';
$lang['source']                = 'Προέλευση:';
$lang['unknown']               = 'άγνωστο';
$lang['updating']              = 'Σε διαδικασία ενημέρωσης ...';
$lang['updated']               = 'Η επέκταση %s ενημερώθηκε με επιτυχία';
$lang['updates']               = 'Οι παρακάτω επεκτάσεις ενημερώθηκαν με επιτυχία:';
$lang['update_none']           = 'Δεν βρέθηκαν ενημερώσεις.';
$lang['deleting']              = 'Σε διαδικασία διαγραφής ...';
$lang['deleted']               = 'Η επέκταση %s διαγράφηκε.';
$lang['downloading']           = 'Σε διαδικασία μεταφόρτωσης ...';
$lang['downloaded']            = 'Η επέκταση %s εγκαταστάθηκε με επιτυχία';
$lang['downloads']             = 'Οι παρακάτω επεκτάσεις εγκαταστάθηκαν με επιτυχία:';
$lang['download_none']         = 'Δεν βρέθηκαν επεκτάσεις ή εμφανίστηκε κάποιο πρόβλημα κατά την σχετική διαδικασία.';
$lang['plugin']                = 'Επέκταση:';
$lang['components']            = 'Συστατικά';
$lang['noinfo']                = 'Αυτή η επέκταση δεν επέστρεψε κάποια πληροφορία - η επέκταση μπορεί να μην λειτουργεί κανονικά.';
$lang['name']                  = 'Όνομα:';
$lang['date']                  = 'Ημερομηνία:';
$lang['type']                  = 'Τύπος:';
$lang['desc']                  = 'Περιγραφή:';
$lang['author']                = 'Συγγραφέας:';
$lang['www']                   = 'Διεύθυνση στο διαδίκτυο:';
$lang['error']                 = 'Εμφανίστηκε άγνωστο σφάλμα.';
$lang['error_download']        = 'Δεν είναι δυνατή η μεταφόρτωση του αρχείου: %s';
$lang['error_badurl']          = 'Το URL είναι μάλλον λανθασμένο - είναι αδύνατον να εξαχθεί το όνομα αρχείου από αυτό το URL';
$lang['error_dircreate']       = 'Δεν είναι δυνατή η δημιουργία ενός προσωρινού φακέλου αποθήκευσης των μεταφορτώσεων';
$lang['error_decompress']      = 'Δεν είναι δυνατή η αποσυμπίεση των μεταφορτώσεων. Αυτό μπορεί να οφείλεται σε μερική λήψη των μεταφορτώσεων, οπότε θα πρέπει να επαναλάβετε την διαδικασία ή το σύστημά σας δεν μπορεί να διαχειριστεί το συγκεκριμένο είδος συμπίεσης, οπότε θα πρέπει να εγκαταστήσετε την επέκταση χειροκίνητα.';
$lang['error_copy']            = 'Εμφανίστηκε ένα σφάλμα αντιγραφής αρχείων κατά την διάρκεια εγκατάστασης της επέκτασης <em>%s</em>: ο δίσκος μπορεί να είναι γεμάτος ή να μην είναι σωστά ρυθμισμένα τα δικαιώματα πρόσβασης. Αυτό το γεγονός μπορεί να οδήγησε σε μερική εγκατάσταση της επέκτασης και άρα η DokuWiki εγκατάστασή σαςνα εμφανίσει προβλήματα σταθερότητας.';
$lang['error_delete']          = 'Εμφανίστηκε ένα σφάλμα κατά την διαδικασία διαγραφής της επέκτασης <em>%s</em>.  Η πιθανότερη αιτία είναι να μην είναι σωστά ρυθμισμένα τα δικαιώματα πρόσβασης.';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/el/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Christopher Smith <chris@jalakai.co.uk>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 * @author Petros Vidalis <pvidalis@gmail.com>
 * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
 */
$lang['menu']                  = 'Διαχείριση Επεκτάσεων';
$lang['download']              = 'Κατεβάστε και εγκαταστήστε μια νέα επέκταση (plugin)';
$lang['manage']                = 'Εγκατεστημένες επεκτάσεις';
$lang['btn_info']              = 'πληροφορίες';
$lang['btn_update']            = 'ενημέρωση';
$lang['btn_delete']            = 'διαγραφή';
$lang['btn_settings']          = 'ρυθμίσεις';
$lang['btn_download']          = 'Μεταφόρτωση';
$lang['btn_enable']            = 'Αποθήκευση';
$lang['url']                   = 'URL';
$lang['installed']             = 'Εγκατεστημένη:';
$lang['lastupdate']            = 'Τελευταία ενημέρωση:';
$lang['source']                = 'Προέλευση:';
$lang['unknown']               = 'άγνωστο';
$lang['updating']              = 'Σε διαδικασία ενημέρωσης ...';
$lang['updated']               = 'Η επέκταση %s ενημερώθηκε με επιτυχία';
$lang['updates']               = 'Οι παρακάτω επεκτάσεις ενημερώθηκαν με επιτυχία:';
$lang['update_none']           = 'Δεν βρέθηκαν ενημερώσεις.';
$lang['deleting']              = 'Σε διαδικασία διαγραφής ...';
$lang['deleted']               = 'Η επέκταση %s διαγράφηκε.';
$lang['downloading']           = 'Σε διαδικασία μεταφόρτωσης ...';
$lang['downloaded']            = 'Η επέκταση %s εγκαταστάθηκε με επιτυχία';
$lang['downloads']             = 'Οι παρακάτω επεκτάσεις εγκαταστάθηκαν με επιτυχία:';
$lang['download_none']         = 'Δεν βρέθηκαν επεκτάσεις ή εμφανίστηκε κάποιο πρόβλημα κατά την σχετική διαδικασία.';
$lang['plugin']                = 'Επέκταση:';
$lang['components']            = 'Συστατικά';
$lang['noinfo']                = 'Αυτή η επέκταση δεν επέστρεψε κάποια πληροφορία - η επέκταση μπορεί να μην λειτουργεί κανονικά.';
$lang['name']                  = 'Όνομα:';
$lang['date']                  = 'Ημερομηνία:';
$lang['type']                  = 'Τύπος:';
$lang['desc']                  = 'Περιγραφή:';
$lang['author']                = 'Συγγραφέας:';
$lang['www']                   = 'Διεύθυνση στο διαδίκτυο:';
$lang['error']                 = 'Εμφανίστηκε άγνωστο σφάλμα.';
$lang['error_download']        = 'Δεν είναι δυνατή η μεταφόρτωση του αρχείου: %s';
$lang['error_badurl']          = 'Το URL είναι μάλλον λανθασμένο - είναι αδύνατον να εξαχθεί το όνομα αρχείου από αυτό το URL';
$lang['error_dircreate']       = 'Δεν είναι δυνατή η δημιουργία ενός προσωρινού φακέλου αποθήκευσης των μεταφορτώσεων';
$lang['error_decompress']      = 'Δεν είναι δυνατή η αποσυμπίεση των μεταφορτώσεων. Αυτό μπορεί να οφείλεται σε μερική λήψη των μεταφορτώσεων, οπότε θα πρέπει να επαναλάβετε την διαδικασία ή το σύστημά σας δεν μπορεί να διαχειριστεί το συγκεκριμένο είδος συμπίεσης, οπότε θα πρέπει να εγκαταστήσετε την επέκταση χειροκίνητα.';
$lang['error_copy']            = 'Εμφανίστηκε ένα σφάλμα αντιγραφής αρχείων κατά την διάρκεια εγκατάστασης της επέκτασης <em>%s</em>: ο δίσκος μπορεί να είναι γεμάτος ή να μην είναι σωστά ρυθμισμένα τα δικαιώματα πρόσβασης. Αυτό το γεγονός μπορεί να οδήγησε σε μερική εγκατάσταση της επέκτασης και άρα η DokuWiki εγκατάστασή σας να εμφανίσει προβλήματα σταθερότητας.';
$lang['error_delete']          = 'Εμφανίστηκε ένα σφάλμα κατά την διαδικασία διαγραφής της επέκτασης <em>%s</em>.  Η πιθανότερη αιτία είναι να μην είναι σωστά ρυθμισμένα τα δικαιώματα πρόσβασης.';
$lang['enabled']               = 'Η επέκταση %s ενεργοποιήθηκε.';
$lang['notenabled']            = 'Η επέκταση %s δεν μπορεί να ενεργοποιηθεί. Ελέγξτε τα δικαιώματα πρόσβασης.';
$lang['disabled']              = 'Η επέκταση %s απενεργοποιήθηκε.';
$lang['notdisabled']           = 'Η επέκταση %s δεν μπορεί να απενεργοποιηθεί. Ελέγξτε τα δικαιώματα πρόσβασης.';
$lang['packageinstalled']      = 'Το πακέτο της επέκτασης (%d επέκταση(εις): %s) εγκαστήθηκε επιτυχημένα.';
